@@ -7,12 +7,15 @@ from functools import partial
 from typing import (
     TYPE_CHECKING,
     Any,
+    Callable,
     ClassVar,
+    ContextManager,
     Generator,
     Iterable,
     List,
     Literal,
     Optional,
+    Protocol,
     Tuple,
     Union,
 )
@@ -26,6 +29,9 @@ from .lazy_django import skip_if_no_django
 
 if TYPE_CHECKING:
     import django
+    import django.test
+
+    from . import DjangoDbBlocker
 
 
 _DjangoDbDatabases = Optional[Union[Literal["__all__"], Iterable[str]]]
@@ -113,7 +119,7 @@ def django_db_createdb(request: pytest.FixtureRequest) -> bool:
 def django_db_setup(
     request: pytest.FixtureRequest,
     django_test_environment: None,
-    django_db_blocker,
+    django_db_blocker: DjangoDbBlocker,
     django_db_use_migrations: bool,
     django_db_keepdb: bool,
     django_db_createdb: bool,
@@ -153,7 +159,7 @@ def django_db_setup(
 def _django_db_helper(
     request: pytest.FixtureRequest,
     django_db_setup: None,
-    django_db_blocker,
+    django_db_blocker: DjangoDbBlocker,
 ) -> Generator[None, None, None]:
     from django import VERSION
 
@@ -393,21 +399,21 @@ def django_db_serialized_rollback(
 
 
 @pytest.fixture()
-def client() -> django.test.client.Client:
+def client() -> django.test.Client:
     """A Django test client instance."""
     skip_if_no_django()
 
-    from django.test.client import Client
+    from django.test import Client
 
     return Client()
 
 
 @pytest.fixture()
-def async_client() -> django.test.client.AsyncClient:
+def async_client() -> django.test.AsyncClient:
     """A Django test async client instance."""
     skip_if_no_django()
 
-    from django.test.client import AsyncClient
+    from django.test import AsyncClient
 
     return AsyncClient()
 
@@ -462,9 +468,9 @@ def admin_user(
 def admin_client(
     db: None,
     admin_user,
-) -> django.test.client.Client:
+) -> django.test.Client:
     """A Django test client logged in as an admin user."""
-    from django.test.client import Client
+    from django.test import Client
 
     client = Client()
     client.force_login(admin_user)
@@ -472,21 +478,21 @@ def admin_client(
 
 
 @pytest.fixture()
-def rf() -> django.test.client.RequestFactory:
+def rf() -> django.test.RequestFactory:
     """RequestFactory instance"""
     skip_if_no_django()
 
-    from django.test.client import RequestFactory
+    from django.test import RequestFactory
 
     return RequestFactory()
 
 
 @pytest.fixture()
-def async_rf() -> django.test.client.AsyncRequestFactory:
+def async_rf() -> django.test.AsyncRequestFactory:
     """AsyncRequestFactory instance"""
     skip_if_no_django()
 
-    from django.test.client import AsyncRequestFactory
+    from django.test import AsyncRequestFactory
 
     return AsyncRequestFactory()
 
@@ -595,13 +601,26 @@ def _live_server_helper(request: pytest.FixtureRequest) -> Generator[None, None,
     live_server._live_server_modified_settings.disable()
 
 
+class DjangoAssertNumQueries(Protocol):
+    """The type of the `django_assert_num_queries` and
+    `django_assert_max_num_queries` fixtures."""
+
+    def __call__(
+        self,
+        num: int,
+        connection: Any | None = ...,
+        info: str | None = ...,
+    ) -> django.test.utils.CaptureQueriesContext:
+        pass  # pragma: no cover
+
+
 @contextmanager
 def _assert_num_queries(
-    config,
+    config: pytest.Config,
     num: int,
     exact: bool = True,
-    connection=None,
-    info=None,
+    connection: Any | None = None,
+    info: str | None = None,
 ) -> Generator[django.test.utils.CaptureQueriesContext, None, None]:
     from django.test.utils import CaptureQueriesContext
 
@@ -635,17 +654,29 @@ def _assert_num_queries(
 
 
 @pytest.fixture()
-def django_assert_num_queries(pytestconfig):
+def django_assert_num_queries(pytestconfig: pytest.Config) -> DjangoAssertNumQueries:
     return partial(_assert_num_queries, pytestconfig)
 
 
 @pytest.fixture()
-def django_assert_max_num_queries(pytestconfig):
+def django_assert_max_num_queries(pytestconfig: pytest.Config) -> DjangoAssertNumQueries:
     return partial(_assert_num_queries, pytestconfig, exact=False)
 
 
+class DjangoCaptureOnCommitCallbacks(Protocol):
+    """The type of the `django_capture_on_commit_callbacks` fixture."""
+
+    def __call__(
+        self,
+        *,
+        using: str = ...,
+        execute: bool = ...,
+    ) -> ContextManager[list[Callable[[], Any]]]:
+        pass  # pragma: no cover
+
+
 @pytest.fixture()
-def django_capture_on_commit_callbacks():
+def django_capture_on_commit_callbacks() -> DjangoCaptureOnCommitCallbacks:
     from django.test import TestCase
 
-    return TestCase.captureOnCommitCallbacks
+    return TestCase.captureOnCommitCallbacks  # type: ignore[no-any-return]
