@@ -10,6 +10,7 @@ import inspect
 import os
 import pathlib
 import sys
+import types
 from functools import reduce
 from typing import TYPE_CHECKING, ContextManager, Generator, List, NoReturn
 
@@ -219,7 +220,7 @@ def _add_django_project_to_path(args) -> str:
     return PROJECT_NOT_FOUND
 
 
-def _setup_django() -> None:
+def _setup_django(config: pytest.Config) -> None:
     if "django" not in sys.modules:
         return
 
@@ -234,7 +235,8 @@ def _setup_django() -> None:
     if not django.apps.apps.ready:
         django.setup()
 
-    _blocking_manager.block()
+    blocking_manager = config.stash[blocking_manager_key]
+    blocking_manager.block()
 
 
 def _get_boolean_value(
@@ -353,14 +355,16 @@ def pytest_load_initial_conftests(
         with _handle_import_error(_django_project_scan_outcome):
             dj_settings.DATABASES  # noqa: B018
 
-    _setup_django()
+    early_config.stash[blocking_manager_key] = DjangoDbBlocker(_ispytest=True)
+
+    _setup_django(early_config)
 
 
 @pytest.hookimpl(trylast=True)
-def pytest_configure() -> None:
+def pytest_configure(config: pytest.Config) -> None:
     # Allow Django settings to be configured in a user pytest_configure call,
     # but make sure we call django.setup()
-    _setup_django()
+    _setup_django(config)
 
 
 @pytest.hookimpl()
@@ -378,6 +382,8 @@ def pytest_report_header(config: pytest.Config) -> list[str] | None:
 
 
 # Convert Django test tags on test classes to pytest marks.
+# Unlike the Django test runner, we only check tags on Django
+# test classes, to keep the plugin's effect contained.
 def pytest_collectstart(collector: pytest.Collector) -> None:
     if "django" not in sys.modules:
         return
@@ -389,9 +395,9 @@ def pytest_collectstart(collector: pytest.Collector) -> None:
     if not tags:
         return
 
-    from django.test import TransactionTestCase
+    from django.test import SimpleTestCase
 
-    if not issubclass(collector.obj, TransactionTestCase):
+    if not issubclass(collector.obj, SimpleTestCase):
         return
 
     for tag in tags:
@@ -410,9 +416,9 @@ def pytest_itemcollected(item: pytest.Item) -> None:
     if not tags:
         return
 
-    from django.test import TransactionTestCase
+    from django.test import SimpleTestCase
 
-    if not issubclass(item.cls, TransactionTestCase):
+    if not issubclass(item.cls, SimpleTestCase):
         return
 
     for tag in tags:
@@ -475,7 +481,7 @@ def django_test_environment(request: pytest.FixtureRequest) -> Generator[None, N
         we need to follow this model.
     """
     if django_settings_is_configured():
-        _setup_django()
+        _setup_django(request.config)
         from django.test.utils import setup_test_environment, teardown_test_environment
 
         debug_ini = request.config.getini("django_debug_mode")
@@ -493,7 +499,7 @@ def django_test_environment(request: pytest.FixtureRequest) -> Generator[None, N
 
 
 @pytest.fixture(scope="session")
-def django_db_blocker() -> _DatabaseBlocker | None:
+def django_db_blocker(request: pytest.FixtureRequest) -> DjangoDbBlocker | None:
     """Wrapper around Django's database access.
 
     This object can be used to re-enable database access.  This fixture is used
@@ -509,7 +515,8 @@ def django_db_blocker() -> _DatabaseBlocker | None:
     if not django_settings_is_configured():
         return None
 
-    return _blocking_manager
+    blocking_manager = request.config.stash[blocking_manager_key]
+    return blocking_manager
 
 
 @pytest.fixture(autouse=True)
@@ -523,7 +530,7 @@ def _django_db_marker(request: pytest.FixtureRequest) -> None:
 @pytest.fixture(autouse=True, scope="class")
 def _django_setup_unittest(
     request: pytest.FixtureRequest,
-    django_db_blocker: _DatabaseBlocker,
+    django_db_blocker: DjangoDbBlocker,
 ) -> Generator[None, None, None]:
     """Setup a django unittest, internal to pytest-django."""
     if not django_settings_is_configured() or not is_django_unittest(request):
@@ -741,23 +748,34 @@ def _django_clear_site_cache() -> None:
 
 
 class _DatabaseBlockerContextManager:
-    def __init__(self, db_blocker) -> None:
+    def __init__(self, db_blocker: DjangoDbBlocker) -> None:
         self._db_blocker = db_blocker
 
     def __enter__(self) -> None:
         pass
 
-    def __exit__(self, exc_type, exc_value, traceback) -> None:
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        traceback: types.TracebackType | None,
+    ) -> None:
         self._db_blocker.restore()
 
 
-class _DatabaseBlocker:
+class DjangoDbBlocker:
     """Manager for django.db.backends.base.base.BaseDatabaseWrapper.
 
     This is the object returned by django_db_blocker.
     """
 
-    def __init__(self) -> None:
+    def __init__(self, *, _ispytest: bool = False) -> None:
+        if not _ispytest:  # pragma: no cover
+            raise TypeError(
+                "The DjangoDbBlocker constructor is private. "
+                "use the django_db_blocker fixture instead."
+            )
+
         self._history = []  # type: ignore[var-annotated]
         self._real_ensure_connection = None
 
@@ -799,7 +817,8 @@ class _DatabaseBlocker:
         self._dj_db_wrapper.ensure_connection = self._history.pop()
 
 
-_blocking_manager = _DatabaseBlocker()
+# On Config.stash.
+blocking_manager_key = pytest.StashKey[DjangoDbBlocker]()
 
 
 def validate_urls(marker) -> list[str]:
